@@ -4,14 +4,14 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.thumbnail.ThumbnailTD
 
 /**
  * 
- * @author giancarlo email: <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  *
  */
 public class InternalURITD extends ResourceTD {
 	private static final long serialVersionUID = -3230438212164027113L;
 
-	private String url;
+	private String id;
 
 	private String mimeType;
 
@@ -21,30 +21,24 @@ public class InternalURITD extends ResourceTD {
 		super();
 	}
 
-	/**
-	 * 
-	 * @param fileId
-	 * @param url
-	 */
-	public InternalURITD(String url,
-			String mimeType, ThumbnailTD thumbnailTD) {
-		super(url);
-		this.url = url;
-		this.mimeType=mimeType;
-		this.thumbnailTD=thumbnailTD;
+	public InternalURITD(String id, String mimeType, ThumbnailTD thumbnailTD) {
+		super(id);
+		this.id = id;
+		this.mimeType = mimeType;
+		this.thumbnailTD = thumbnailTD;
 	}
 
 	@Override
 	public String getStringValue() {
-		return url;
+		return id;
 	}
 
-	public String getUrl() {
-		return url;
+	public String getId() {
+		return id;
 	}
 
-	public void setUrl(String url) {
-		this.url = url;
+	public void setId(String id) {
+		this.id = id;
 	}
 
 	public String getMimeType() {
@@ -65,12 +59,7 @@ public class InternalURITD extends ResourceTD {
 
 	@Override
 	public String toString() {
-		return "InternalURITD [url=" + url + ", mimeType=" + mimeType
-				+ ", thumbnailTD=" + thumbnailTD + "]";
+		return "InternalURITD [id=" + id + ", mimeType=" + mimeType + ", thumbnailTD=" + thumbnailTD + "]";
 	}
 
-	
-	
-
-	
 }
